DocuSign v0.2.3 DocuSign.Api.PaymentGatewayAccounts View Source
API calls for all endpoints tagged PaymentGatewayAccounts.
Link to this section Summary
Functions
List payment gateway account information List payment gateway account information
Link to this section Functions
Link to this function
payment_gateway_accounts_get_all_payment_gateway_accounts(connection, account_id, opts \\ [])
View Sourcepayment_gateway_accounts_get_all_payment_gateway_accounts( Tesla.Env.client(), String.t(), keyword() ) :: {:ok, DocuSign.Model.PaymentGatewayAccountsInfo.t()} | {:error, Tesla.Env.t()}
List payment gateway account information List payment gateway account information
Parameters
- connection (DocuSign.Connection): Connection to server
- account_id (String.t): The external account number (int) or account ID Guid.
- opts (KeywordList): [optional] Optional parameters
Returns
{:ok, %DocuSign.Model.PaymentGatewayAccountsInfo{}} on success {:error, info} on failure