Brands use resource files to style the following experiences: - Email - Sending - Signing - Captive (embedded) signing You can modify these resource files to customize these experiences.
@type t() :: %DocuSign.Model.BrandResourceUrls{ email: String.t() | nil, sending: String.t() | nil, signing: String.t() | nil, signingCaptive: String.t() | nil }