The bulk send list resource provides methods that enable you to create and manage bulk sending lists, which you can use to send multiple copies of an envelope in a single batch. Note: The Bulk Send feature is only available on Business Pro and Enterprise Pro plans.
Summary
Types
@type t() :: %DocuSign.Model.BulkSend{ bulkCopies: [DocuSign.Model.BulkSendingCopy.t()] | nil, listId: String.t() | nil, name: String.t() | nil }