This object contains details about a custom field for a bulk send copy. In a bulk send request, each custom field in the bulk send list must match a custom field in the envelope or template that you want to send.
@type t() :: %DocuSign.Model.BulkSendingCopyCustomField{ name: String.t() | nil, value: String.t() | nil }