This object contains the details for the bulk send list.
Summary
Types
@type t() :: %DocuSign.Model.BulkSendingList{ bulkCopies: [DocuSign.Model.BulkSendingCopy.t()] | nil, listId: String.t() | nil, name: String.t() | nil }
This object contains the details for the bulk send list.
@type t() :: %DocuSign.Model.BulkSendingList{ bulkCopies: [DocuSign.Model.BulkSendingCopy.t()] | nil, listId: String.t() | nil, name: String.t() | nil }