This object is used to match a Docusign field to a Salesforce field so that Docusign can send information to your Salesforce account.
@type t() :: %DocuSign.Model.ConnectSalesforceField{ dsAttribute: String.t() | nil, dsLink: String.t() | nil, dsNode: String.t() | nil, id: String.t() | nil, sfField: String.t() | nil, sfFieldName: String.t() | nil, sfFolder: String.t() | nil, sfLockedValue: String.t() | nil }