Contains information about the current envelope purge configuration for an account, which enables account administrators to purge documents from completed and voided envelopes after a set number of days (retentionDays).
retentionDays
@type t() :: %DocuSign.Model.EnvelopePurgeConfiguration{ purgeEnvelopes: String.t() | nil, redactPII: String.t() | nil, removeTabsAndEnvelopeAttachments: String.t() | nil, retentionDays: String.t() | nil }