This object contains information about a payment method that the gateway accepts and the payment options that are compatible with it.
@type t() :: %DocuSign.Model.PaymentMethodWithOptions{ supportedCurrencies: [String.t()] | nil, supportedOptions: [String.t()] | nil, type: String.t() | nil }