This resource is used to create a responsive preview of all of the documents in an envelope.
Summary
Types
@type t() :: %DocuSign.Model.ResponsiveHtmlPreview{ htmlDefinitions: [String.t()] | nil }
This resource is used to create a responsive preview of all of the documents in an envelope.
@type t() :: %DocuSign.Model.ResponsiveHtmlPreview{ htmlDefinitions: [String.t()] | nil }