This resource is used to create a responsive preview of a specific template document.
Summary
Types
@type t() :: %DocuSign.Model.TemplateDocumentResponsiveHtmlPreview{ htmlDefinitions: [String.t()] | nil }
This resource is used to create a responsive preview of a specific template document.
@type t() :: %DocuSign.Model.TemplateDocumentResponsiveHtmlPreview{ htmlDefinitions: [String.t()] | nil }